.. currentmodule:: sardana.pool.poolpseudomotor

.. _sardana-pseudomotor-api:

=============================
Pseudo motor API reference
=============================

.. todo:: document pseudo-motor API reference

.. seealso:: 
    
    :ref:`sardana-pseudomotor-overview`
        the pseudo-motor overview 
    
    :class:`~sardana.tango.pool.PseudoMotor.PseudoMotor`
        the pseudo-motor tango device :term:`API`

..    :class:`~sardana.pool.poolpseudomotor.PoolPseudoMotor`
..        the pseudo-motor class :term:`API`
